UserAnalyticsInternal class

Constructors

UserAnalyticsInternal()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

logClickEvent(String pageName, String controlName, Map<String, String>? params) → void
logCustomEvent(String pageName, String customeEventName, Map<String, String>? params) → void
logExposureEvent(String pageName, String exposureName, Map<String, String>? params) → void
pageAppear(String pageName, Map<String, String>? params) → void
pageDisappear() → void
setDefaultEventParameters(Map<String, String>? params) → void
updatePageParameters(String pageName, Map<String, String>? params) → void